mocks

package
v0.20.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 20, 2025 License: MIT Imports: 13 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockCertificatesChargePointHandler

type MockCertificatesChargePointHandler struct {
	mock.Mock
}

MockCertificatesChargePointHandler is an autogenerated mock type for the ChargePointHandler type

func NewMockCertificatesChargePointHandler

func NewMockCertificatesChargePointHandler(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockCertificatesChargePointHandler

NewMockCertificatesChargePointHandler creates a new instance of MockCertificatesChargePointHandler. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockCertificatesChargePointHandler) EXPECT

func (*MockCertificatesChargePointHandler) OnDeleteCertificate

OnDeleteCertificate provides a mock function with given fields: request

func (*MockCertificatesChargePointHandler) OnGetInstalledCertificateIds

OnGetInstalledCertificateIds provides a mock function with given fields: request

func (*MockCertificatesChargePointHandler) OnInstallCertificate

OnInstallCertificate provides a mock function with given fields: request

type MockCertificatesChargePointHandler_Expecter

type MockCertificatesChargePointHandler_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockCertificatesChargePointHandler_Expecter) OnDeleteCertificate

OnDeleteCertificate is a helper method to define mock.On call

  • request *certificates.DeleteCertificateRequest

func (*MockCertificatesChargePointHandler_Expecter) OnGetInstalledCertificateIds

OnGetInstalledCertificateIds is a helper method to define mock.On call

  • request *certificates.GetInstalledCertificateIdsRequest

func (*MockCertificatesChargePointHandler_Expecter) OnInstallCertificate

OnInstallCertificate is a helper method to define mock.On call

  • request *certificates.InstallCertificateRequest

type MockCertificatesChargePointHandler_OnDeleteCertificate_Call

type MockCertificatesChargePointHandler_OnDeleteCertificate_Call struct {
	*mock.Call
}

MockCertificatesChargePointHandler_OnDeleteCertificate_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OnDeleteCertificate'

func (*MockCertificatesChargePointHandler_OnDeleteCertificate_Call) Return

func (*MockCertificatesChargePointHandler_OnDeleteCertificate_Call) Run

type MockCertificatesChargePointHandler_OnGetInstalledCertificateIds_Call

type MockCertificatesChargePointHandler_OnGetInstalledCertificateIds_Call struct {
	*mock.Call
}

MockCertificatesChargePointHandler_OnGetInstalledCertificateIds_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OnGetInstalledCertificateIds'

func (*MockCertificatesChargePointHandler_OnGetInstalledCertificateIds_Call) Return

func (*MockCertificatesChargePointHandler_OnGetInstalledCertificateIds_Call) Run

type MockCertificatesChargePointHandler_OnInstallCertificate_Call

type MockCertificatesChargePointHandler_OnInstallCertificate_Call struct {
	*mock.Call
}

MockCertificatesChargePointHandler_OnInstallCertificate_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OnInstallCertificate'

func (*MockCertificatesChargePointHandler_OnInstallCertificate_Call) Return

func (*MockCertificatesChargePointHandler_OnInstallCertificate_Call) Run

type MockChargePointConnectionHandler

type MockChargePointConnectionHandler struct {
	mock.Mock
}

MockChargePointConnectionHandler is an autogenerated mock type for the ChargePointConnectionHandler type

func NewMockChargePointConnectionHandler

func NewMockChargePointConnectionHandler(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockChargePointConnectionHandler

NewMockChargePointConnectionHandler creates a new instance of MockChargePointConnectionHandler. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockChargePointConnectionHandler) EXPECT

func (*MockChargePointConnectionHandler) Execute

Execute provides a mock function with given fields: chargePoint

type MockChargePointConnectionHandler_Execute_Call

type MockChargePointConnectionHandler_Execute_Call struct {
	*mock.Call
}

MockChargePointConnectionHandler_Execute_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Execute'

func (*MockChargePointConnectionHandler_Execute_Call) Return

func (*MockChargePointConnectionHandler_Execute_Call) Run

func (*MockChargePointConnectionHandler_Execute_Call) RunAndReturn

type MockChargePointConnectionHandler_Expecter

type MockChargePointConnectionHandler_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockChargePointConnectionHandler_Expecter) Execute

Execute is a helper method to define mock.On call

  • chargePoint ocpp16.ChargePointConnection

type MockCoreCentralSystemHandler

type MockCoreCentralSystemHandler struct {
	mock.Mock
}

MockCoreCentralSystemHandler is an autogenerated mock type for the CentralSystemHandler type

func NewMockCoreCentralSystemHandler

func NewMockCoreCentralSystemHandler(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockCoreCentralSystemHandler

NewMockCoreCentralSystemHandler creates a new instance of MockCoreCentralSystemHandler. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockCoreCentralSystemHandler) EXPECT

func (*MockCoreCentralSystemHandler) OnAuthorize

func (_m *MockCoreCentralSystemHandler) OnAuthorize(chargePointId string, request *core.AuthorizeRequest) (*core.AuthorizeConfirmation, error)

OnAuthorize provides a mock function with given fields: chargePointId, request

func (*MockCoreCentralSystemHandler) OnBootNotification

func (_m *MockCoreCentralSystemHandler) OnBootNotification(chargePointId string, request *core.BootNotificationRequest) (*core.BootNotificationConfirmation, error)

OnBootNotification provides a mock function with given fields: chargePointId, request

func (*MockCoreCentralSystemHandler) OnDataTransfer

func (_m *MockCoreCentralSystemHandler) OnDataTransfer(chargePointId string, request *core.DataTransferRequest) (*core.DataTransferConfirmation, error)

OnDataTransfer provides a mock function with given fields: chargePointId, request

func (*MockCoreCentralSystemHandler) OnHeartbeat

func (_m *MockCoreCentralSystemHandler) OnHeartbeat(chargePointId string, request *core.HeartbeatRequest) (*core.HeartbeatConfirmation, error)

OnHeartbeat provides a mock function with given fields: chargePointId, request

func (*MockCoreCentralSystemHandler) OnMeterValues

func (_m *MockCoreCentralSystemHandler) OnMeterValues(chargePointId string, request *core.MeterValuesRequest) (*core.MeterValuesConfirmation, error)

OnMeterValues provides a mock function with given fields: chargePointId, request

func (*MockCoreCentralSystemHandler) OnStartTransaction

func (_m *MockCoreCentralSystemHandler) OnStartTransaction(chargePointId string, request *core.StartTransactionRequest) (*core.StartTransactionConfirmation, error)

OnStartTransaction provides a mock function with given fields: chargePointId, request

func (*MockCoreCentralSystemHandler) OnStatusNotification

func (_m *MockCoreCentralSystemHandler) OnStatusNotification(chargePointId string, request *core.StatusNotificationRequest) (*core.StatusNotificationConfirmation, error)

OnStatusNotification provides a mock function with given fields: chargePointId, request

func (*MockCoreCentralSystemHandler) OnStopTransaction

func (_m *MockCoreCentralSystemHandler) OnStopTransaction(chargePointId string, request *core.StopTransactionRequest) (*core.StopTransactionConfirmation, error)

OnStopTransaction provides a mock function with given fields: chargePointId, request

type MockCoreCentralSystemHandler_Expecter

type MockCoreCentralSystemHandler_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockCoreCentralSystemHandler_Expecter) OnAuthorize

func (_e *MockCoreCentralSystemHandler_Expecter) OnAuthorize(chargePointId interface{}, request interface{}) *MockCoreCentralSystemHandler_OnAuthorize_Call

OnAuthorize is a helper method to define mock.On call

  • chargePointId string
  • request *core.AuthorizeRequest

func (*MockCoreCentralSystemHandler_Expecter) OnBootNotification

func (_e *MockCoreCentralSystemHandler_Expecter) OnBootNotification(chargePointId interface{}, request interface{}) *MockCoreCentralSystemHandler_OnBootNotification_Call

OnBootNotification is a helper method to define mock.On call

  • chargePointId string
  • request *core.BootNotificationRequest

func (*MockCoreCentralSystemHandler_Expecter) OnDataTransfer

func (_e *MockCoreCentralSystemHandler_Expecter) OnDataTransfer(chargePointId interface{}, request interface{}) *MockCoreCentralSystemHandler_OnDataTransfer_Call

OnDataTransfer is a helper method to define mock.On call

  • chargePointId string
  • request *core.DataTransferRequest

func (*MockCoreCentralSystemHandler_Expecter) OnHeartbeat

func (_e *MockCoreCentralSystemHandler_Expecter) OnHeartbeat(chargePointId interface{}, request interface{}) *MockCoreCentralSystemHandler_OnHeartbeat_Call

OnHeartbeat is a helper method to define mock.On call

  • chargePointId string
  • request *core.HeartbeatRequest

func (*MockCoreCentralSystemHandler_Expecter) OnMeterValues

func (_e *MockCoreCentralSystemHandler_Expecter) OnMeterValues(chargePointId interface{}, request interface{}) *MockCoreCentralSystemHandler_OnMeterValues_Call

OnMeterValues is a helper method to define mock.On call

  • chargePointId string
  • request *core.MeterValuesRequest

func (*MockCoreCentralSystemHandler_Expecter) OnStartTransaction

func (_e *MockCoreCentralSystemHandler_Expecter) OnStartTransaction(chargePointId interface{}, request interface{}) *MockCoreCentralSystemHandler_OnStartTransaction_Call

OnStartTransaction is a helper method to define mock.On call

  • chargePointId string
  • request *core.StartTransactionRequest

func (*MockCoreCentralSystemHandler_Expecter) OnStatusNotification

func (_e *MockCoreCentralSystemHandler_Expecter) OnStatusNotification(chargePointId interface{}, request interface{}) *MockCoreCentralSystemHandler_OnStatusNotification_Call

OnStatusNotification is a helper method to define mock.On call

  • chargePointId string
  • request *core.StatusNotificationRequest

func (*MockCoreCentralSystemHandler_Expecter) OnStopTransaction

func (_e *MockCoreCentralSystemHandler_Expecter) OnStopTransaction(chargePointId interface{}, request interface{}) *MockCoreCentralSystemHandler_OnStopTransaction_Call

OnStopTransaction is a helper method to define mock.On call

  • chargePointId string
  • request *core.StopTransactionRequest

type MockCoreCentralSystemHandler_OnAuthorize_Call

type MockCoreCentralSystemHandler_OnAuthorize_Call struct {
	*mock.Call
}

MockCoreCentralSystemHandler_OnAuthorize_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OnAuthorize'

func (*MockCoreCentralSystemHandler_OnAuthorize_Call) Return

func (*MockCoreCentralSystemHandler_OnAuthorize_Call) Run

func (*MockCoreCentralSystemHandler_OnAuthorize_Call) RunAndReturn

type MockCoreCentralSystemHandler_OnBootNotification_Call

type MockCoreCentralSystemHandler_OnBootNotification_Call struct {
	*mock.Call
}

MockCoreCentralSystemHandler_OnBootNotification_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OnBootNotification'

func (*MockCoreCentralSystemHandler_OnBootNotification_Call) Return

func (*MockCoreCentralSystemHandler_OnBootNotification_Call) Run

func (*MockCoreCentralSystemHandler_OnBootNotification_Call) RunAndReturn

type MockCoreCentralSystemHandler_OnDataTransfer_Call

type MockCoreCentralSystemHandler_OnDataTransfer_Call struct {
	*mock.Call
}

MockCoreCentralSystemHandler_OnDataTransfer_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OnDataTransfer'

func (*MockCoreCentralSystemHandler_OnDataTransfer_Call) Return

func (*MockCoreCentralSystemHandler_OnDataTransfer_Call) Run

func (*MockCoreCentralSystemHandler_OnDataTransfer_Call) RunAndReturn

type MockCoreCentralSystemHandler_OnHeartbeat_Call

type MockCoreCentralSystemHandler_OnHeartbeat_Call struct {
	*mock.Call
}

MockCoreCentralSystemHandler_OnHeartbeat_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OnHeartbeat'

func (*MockCoreCentralSystemHandler_OnHeartbeat_Call) Return

func (*MockCoreCentralSystemHandler_OnHeartbeat_Call) Run

func (*MockCoreCentralSystemHandler_OnHeartbeat_Call) RunAndReturn

type MockCoreCentralSystemHandler_OnMeterValues_Call

type MockCoreCentralSystemHandler_OnMeterValues_Call struct {
	*mock.Call
}

MockCoreCentralSystemHandler_OnMeterValues_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OnMeterValues'

func (*MockCoreCentralSystemHandler_OnMeterValues_Call) Return

func (*MockCoreCentralSystemHandler_OnMeterValues_Call) Run

func (*MockCoreCentralSystemHandler_OnMeterValues_Call) RunAndReturn

type MockCoreCentralSystemHandler_OnStartTransaction_Call

type MockCoreCentralSystemHandler_OnStartTransaction_Call struct {
	*mock.Call
}

MockCoreCentralSystemHandler_OnStartTransaction_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OnStartTransaction'

func (*MockCoreCentralSystemHandler_OnStartTransaction_Call) Return

func (*MockCoreCentralSystemHandler_OnStartTransaction_Call) Run

func (*MockCoreCentralSystemHandler_OnStartTransaction_Call) RunAndReturn

type MockCoreCentralSystemHandler_OnStatusNotification_Call

type MockCoreCentralSystemHandler_OnStatusNotification_Call struct {
	*mock.Call
}

MockCoreCentralSystemHandler_OnStatusNotification_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OnStatusNotification'

func (*MockCoreCentralSystemHandler_OnStatusNotification_Call) Return

func (*MockCoreCentralSystemHandler_OnStatusNotification_Call) Run

func (*MockCoreCentralSystemHandler_OnStatusNotification_Call) RunAndReturn

type MockCoreCentralSystemHandler_OnStopTransaction_Call

type MockCoreCentralSystemHandler_OnStopTransaction_Call struct {
	*mock.Call
}

MockCoreCentralSystemHandler_OnStopTransaction_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OnStopTransaction'

func (*MockCoreCentralSystemHandler_OnStopTransaction_Call) Return

func (*MockCoreCentralSystemHandler_OnStopTransaction_Call) Run

func (*MockCoreCentralSystemHandler_OnStopTransaction_Call) RunAndReturn

type MockCoreChargePointHandler

type MockCoreChargePointHandler struct {
	mock.Mock
}

MockCoreChargePointHandler is an autogenerated mock type for the ChargePointHandler type

func NewMockCoreChargePointHandler

func NewMockCoreChargePointHandler(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockCoreChargePointHandler

NewMockCoreChargePointHandler creates a new instance of MockCoreChargePointHandler. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockCoreChargePointHandler) EXPECT

func (*MockCoreChargePointHandler) OnChangeAvailability

OnChangeAvailability provides a mock function with given fields: request

func (*MockCoreChargePointHandler) OnChangeConfiguration

OnChangeConfiguration provides a mock function with given fields: request

func (*MockCoreChargePointHandler) OnClearCache

OnClearCache provides a mock function with given fields: request

func (*MockCoreChargePointHandler) OnDataTransfer

OnDataTransfer provides a mock function with given fields: request

func (*MockCoreChargePointHandler) OnGetConfiguration

OnGetConfiguration provides a mock function with given fields: request

func (*MockCoreChargePointHandler) OnRemoteStartTransaction

OnRemoteStartTransaction provides a mock function with given fields: request

func (*MockCoreChargePointHandler) OnRemoteStopTransaction

OnRemoteStopTransaction provides a mock function with given fields: request

func (*MockCoreChargePointHandler) OnReset

OnReset provides a mock function with given fields: request

func (*MockCoreChargePointHandler) OnUnlockConnector

OnUnlockConnector provides a mock function with given fields: request

type MockCoreChargePointHandler_Expecter

type MockCoreChargePointHandler_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockCoreChargePointHandler_Expecter) OnChangeAvailability

OnChangeAvailability is a helper method to define mock.On call

  • request *core.ChangeAvailabilityRequest

func (*MockCoreChargePointHandler_Expecter) OnChangeConfiguration

OnChangeConfiguration is a helper method to define mock.On call

  • request *core.ChangeConfigurationRequest

func (*MockCoreChargePointHandler_Expecter) OnClearCache

OnClearCache is a helper method to define mock.On call

  • request *core.ClearCacheRequest

func (*MockCoreChargePointHandler_Expecter) OnDataTransfer

OnDataTransfer is a helper method to define mock.On call

  • request *core.DataTransferRequest

func (*MockCoreChargePointHandler_Expecter) OnGetConfiguration

OnGetConfiguration is a helper method to define mock.On call

  • request *core.GetConfigurationRequest

func (*MockCoreChargePointHandler_Expecter) OnRemoteStartTransaction

func (_e *MockCoreChargePointHandler_Expecter) OnRemoteStartTransaction(request interface{}) *MockCoreChargePointHandler_OnRemoteStartTransaction_Call

OnRemoteStartTransaction is a helper method to define mock.On call

  • request *core.RemoteStartTransactionRequest

func (*MockCoreChargePointHandler_Expecter) OnRemoteStopTransaction

func (_e *MockCoreChargePointHandler_Expecter) OnRemoteStopTransaction(request interface{}) *MockCoreChargePointHandler_OnRemoteStopTransaction_Call

OnRemoteStopTransaction is a helper method to define mock.On call

  • request *core.RemoteStopTransactionRequest

func (*MockCoreChargePointHandler_Expecter) OnReset

OnReset is a helper method to define mock.On call

  • request *core.ResetRequest

func (*MockCoreChargePointHandler_Expecter) OnUnlockConnector

OnUnlockConnector is a helper method to define mock.On call

  • request *core.UnlockConnectorRequest

type MockCoreChargePointHandler_OnChangeAvailability_Call

type MockCoreChargePointHandler_OnChangeAvailability_Call struct {
	*mock.Call
}

MockCoreChargePointHandler_OnChangeAvailability_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OnChangeAvailability'

func (*MockCoreChargePointHandler_OnChangeAvailability_Call) Return

func (*MockCoreChargePointHandler_OnChangeAvailability_Call) Run

func (*MockCoreChargePointHandler_OnChangeAvailability_Call) RunAndReturn

type MockCoreChargePointHandler_OnChangeConfiguration_Call

type MockCoreChargePointHandler_OnChangeConfiguration_Call struct {
	*mock.Call
}

MockCoreChargePointHandler_OnChangeConfiguration_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OnChangeConfiguration'

func (*MockCoreChargePointHandler_OnChangeConfiguration_Call) Return

func (*MockCoreChargePointHandler_OnChangeConfiguration_Call) Run

func (*MockCoreChargePointHandler_OnChangeConfiguration_Call) RunAndReturn

type MockCoreChargePointHandler_OnClearCache_Call

type MockCoreChargePointHandler_OnClearCache_Call struct {
	*mock.Call
}

MockCoreChargePointHandler_OnClearCache_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OnClearCache'

func (*MockCoreChargePointHandler_OnClearCache_Call) Return

func (*MockCoreChargePointHandler_OnClearCache_Call) Run

func (*MockCoreChargePointHandler_OnClearCache_Call) RunAndReturn

type MockCoreChargePointHandler_OnDataTransfer_Call

type MockCoreChargePointHandler_OnDataTransfer_Call struct {
	*mock.Call
}

MockCoreChargePointHandler_OnDataTransfer_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OnDataTransfer'

func (*MockCoreChargePointHandler_OnDataTransfer_Call) Return

func (*MockCoreChargePointHandler_OnDataTransfer_Call) Run

func (*MockCoreChargePointHandler_OnDataTransfer_Call) RunAndReturn

type MockCoreChargePointHandler_OnGetConfiguration_Call

type MockCoreChargePointHandler_OnGetConfiguration_Call struct {
	*mock.Call
}

MockCoreChargePointHandler_OnGetConfiguration_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OnGetConfiguration'

func (*MockCoreChargePointHandler_OnGetConfiguration_Call) Return

func (*MockCoreChargePointHandler_OnGetConfiguration_Call) Run

func (*MockCoreChargePointHandler_OnGetConfiguration_Call) RunAndReturn

type MockCoreChargePointHandler_OnRemoteStartTransaction_Call

type MockCoreChargePointHandler_OnRemoteStartTransaction_Call struct {
	*mock.Call
}

MockCoreChargePointHandler_OnRemoteStartTransaction_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OnRemoteStartTransaction'

func (*MockCoreChargePointHandler_OnRemoteStartTransaction_Call) Return

func (*MockCoreChargePointHandler_OnRemoteStartTransaction_Call) Run

func (*MockCoreChargePointHandler_OnRemoteStartTransaction_Call) RunAndReturn

type MockCoreChargePointHandler_OnRemoteStopTransaction_Call

type MockCoreChargePointHandler_OnRemoteStopTransaction_Call struct {
	*mock.Call
}

MockCoreChargePointHandler_OnRemoteStopTransaction_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OnRemoteStopTransaction'

func (*MockCoreChargePointHandler_OnRemoteStopTransaction_Call) Return

func (*MockCoreChargePointHandler_OnRemoteStopTransaction_Call) Run

func (*MockCoreChargePointHandler_OnRemoteStopTransaction_Call) RunAndReturn

type MockCoreChargePointHandler_OnReset_Call

type MockCoreChargePointHandler_OnReset_Call struct {
	*mock.Call
}

MockCoreChargePointHandler_OnReset_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OnReset'

func (*MockCoreChargePointHandler_OnReset_Call) Return

func (*MockCoreChargePointHandler_OnReset_Call) Run

func (*MockCoreChargePointHandler_OnReset_Call) RunAndReturn

type MockCoreChargePointHandler_OnUnlockConnector_Call

type MockCoreChargePointHandler_OnUnlockConnector_Call struct {
	*mock.Call
}

MockCoreChargePointHandler_OnUnlockConnector_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OnUnlockConnector'

func (*MockCoreChargePointHandler_OnUnlockConnector_Call) Return

func (*MockCoreChargePointHandler_OnUnlockConnector_Call) Run

func (*MockCoreChargePointHandler_OnUnlockConnector_Call) RunAndReturn

type MockExtendedTriggerMessageChargePointHandler

type MockExtendedTriggerMessageChargePointHandler struct {
	mock.Mock
}

MockExtendedTriggerMessageChargePointHandler is an autogenerated mock type for the ChargePointHandler type

func NewMockExtendedTriggerMessageChargePointHandler

func NewMockExtendedTriggerMessageChargePointHandler(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockExtendedTriggerMessageChargePointHandler

NewMockExtendedTriggerMessageChargePointHandler creates a new instance of MockExtendedTriggerMessageChargePointHandler. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockExtendedTriggerMessageChargePointHandler) EXPECT

func (*MockExtendedTriggerMessageChargePointHandler) OnExtendedTriggerMessage

OnExtendedTriggerMessage provides a mock function with given fields: request

type MockExtendedTriggerMessageChargePointHandler_Expecter

type MockExtendedTriggerMessageChargePointHandler_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockExtendedTriggerMessageChargePointHandler_Expecter) OnExtendedTriggerMessage

OnExtendedTriggerMessage is a helper method to define mock.On call

  • request *extendedtriggermessage.ExtendedTriggerMessageRequest

type MockExtendedTriggerMessageChargePointHandler_OnExtendedTriggerMessage_Call

type MockExtendedTriggerMessageChargePointHandler_OnExtendedTriggerMessage_Call struct {
	*mock.Call
}

MockExtendedTriggerMessageChargePointHandler_OnExtendedTriggerMessage_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OnExtendedTriggerMessage'

type MockFirmwareCentralSystemHandler

type MockFirmwareCentralSystemHandler struct {
	mock.Mock
}

MockFirmwareCentralSystemHandler is an autogenerated mock type for the CentralSystemHandler type

func NewMockFirmwareCentralSystemHandler

func NewMockFirmwareCentralSystemHandler(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockFirmwareCentralSystemHandler

NewMockFirmwareCentralSystemHandler creates a new instance of MockFirmwareCentralSystemHandler. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockFirmwareCentralSystemHandler) EXPECT

func (*MockFirmwareCentralSystemHandler) OnDiagnosticsStatusNotification

OnDiagnosticsStatusNotification provides a mock function with given fields: chargePointId, request

func (*MockFirmwareCentralSystemHandler) OnFirmwareStatusNotification

OnFirmwareStatusNotification provides a mock function with given fields: chargePointId, request

type MockFirmwareCentralSystemHandler_Expecter

type MockFirmwareCentralSystemHandler_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockFirmwareCentralSystemHandler_Expecter) OnDiagnosticsStatusNotification

func (_e *MockFirmwareCentralSystemHandler_Expecter) OnDiagnosticsStatusNotification(chargePointId interface{}, request interface{}) *MockFirmwareCentralSystemHandler_OnDiagnosticsStatusNotification_Call

OnDiagnosticsStatusNotification is a helper method to define mock.On call

  • chargePointId string
  • request *firmware.DiagnosticsStatusNotificationRequest

func (*MockFirmwareCentralSystemHandler_Expecter) OnFirmwareStatusNotification

func (_e *MockFirmwareCentralSystemHandler_Expecter) OnFirmwareStatusNotification(chargePointId interface{}, request interface{}) *MockFirmwareCentralSystemHandler_OnFirmwareStatusNotification_Call

OnFirmwareStatusNotification is a helper method to define mock.On call

  • chargePointId string
  • request *firmware.FirmwareStatusNotificationRequest

type MockFirmwareCentralSystemHandler_OnDiagnosticsStatusNotification_Call

type MockFirmwareCentralSystemHandler_OnDiagnosticsStatusNotification_Call struct {
	*mock.Call
}

MockFirmwareCentralSystemHandler_OnDiagnosticsStatusNotification_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OnDiagnosticsStatusNotification'

func (*MockFirmwareCentralSystemHandler_OnDiagnosticsStatusNotification_Call) Return

func (*MockFirmwareCentralSystemHandler_OnDiagnosticsStatusNotification_Call) Run

type MockFirmwareCentralSystemHandler_OnFirmwareStatusNotification_Call

type MockFirmwareCentralSystemHandler_OnFirmwareStatusNotification_Call struct {
	*mock.Call
}

MockFirmwareCentralSystemHandler_OnFirmwareStatusNotification_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OnFirmwareStatusNotification'

func (*MockFirmwareCentralSystemHandler_OnFirmwareStatusNotification_Call) Return

func (*MockFirmwareCentralSystemHandler_OnFirmwareStatusNotification_Call) Run

type MockFirmwareChargePointHandler

type MockFirmwareChargePointHandler struct {
	mock.Mock
}

MockFirmwareChargePointHandler is an autogenerated mock type for the ChargePointHandler type

func NewMockFirmwareChargePointHandler

func NewMockFirmwareChargePointHandler(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockFirmwareChargePointHandler

NewMockFirmwareChargePointHandler creates a new instance of MockFirmwareChargePointHandler. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockFirmwareChargePointHandler) EXPECT

func (*MockFirmwareChargePointHandler) OnGetDiagnostics

OnGetDiagnostics provides a mock function with given fields: request

func (*MockFirmwareChargePointHandler) OnUpdateFirmware

OnUpdateFirmware provides a mock function with given fields: request

type MockFirmwareChargePointHandler_Expecter

type MockFirmwareChargePointHandler_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockFirmwareChargePointHandler_Expecter) OnGetDiagnostics

OnGetDiagnostics is a helper method to define mock.On call

  • request *firmware.GetDiagnosticsRequest

func (*MockFirmwareChargePointHandler_Expecter) OnUpdateFirmware

OnUpdateFirmware is a helper method to define mock.On call

  • request *firmware.UpdateFirmwareRequest

type MockFirmwareChargePointHandler_OnGetDiagnostics_Call

type MockFirmwareChargePointHandler_OnGetDiagnostics_Call struct {
	*mock.Call
}

MockFirmwareChargePointHandler_OnGetDiagnostics_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OnGetDiagnostics'

func (*MockFirmwareChargePointHandler_OnGetDiagnostics_Call) Return

func (*MockFirmwareChargePointHandler_OnGetDiagnostics_Call) Run

func (*MockFirmwareChargePointHandler_OnGetDiagnostics_Call) RunAndReturn

type MockFirmwareChargePointHandler_OnUpdateFirmware_Call

type MockFirmwareChargePointHandler_OnUpdateFirmware_Call struct {
	*mock.Call
}

MockFirmwareChargePointHandler_OnUpdateFirmware_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OnUpdateFirmware'

func (*MockFirmwareChargePointHandler_OnUpdateFirmware_Call) Return

func (*MockFirmwareChargePointHandler_OnUpdateFirmware_Call) Run

func (*MockFirmwareChargePointHandler_OnUpdateFirmware_Call) RunAndReturn

type MockLocalAuthListCentralSystemHandler

type MockLocalAuthListCentralSystemHandler struct {
	mock.Mock
}

MockLocalAuthListCentralSystemHandler is an autogenerated mock type for the CentralSystemHandler type

func NewMockLocalAuthListCentralSystemHandler

func NewMockLocalAuthListCentralSystemHandler(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockLocalAuthListCentralSystemHandler

NewMockLocalAuthListCentralSystemHandler creates a new instance of MockLocalAuthListCentralSystemHandler. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockLocalAuthListCentralSystemHandler) EXPECT

type MockLocalAuthListCentralSystemHandler_Expecter

type MockLocalAuthListCentralSystemHandler_Expecter struct {
	// contains filtered or unexported fields
}

type MockLocalAuthListChargePointHandler

type MockLocalAuthListChargePointHandler struct {
	mock.Mock
}

MockLocalAuthListChargePointHandler is an autogenerated mock type for the ChargePointHandler type

func NewMockLocalAuthListChargePointHandler

func NewMockLocalAuthListChargePointHandler(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockLocalAuthListChargePointHandler

NewMockLocalAuthListChargePointHandler creates a new instance of MockLocalAuthListChargePointHandler. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockLocalAuthListChargePointHandler) EXPECT

func (*MockLocalAuthListChargePointHandler) OnGetLocalListVersion

OnGetLocalListVersion provides a mock function with given fields: request

func (*MockLocalAuthListChargePointHandler) OnSendLocalList

OnSendLocalList provides a mock function with given fields: request

type MockLocalAuthListChargePointHandler_Expecter

type MockLocalAuthListChargePointHandler_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockLocalAuthListChargePointHandler_Expecter) OnGetLocalListVersion

OnGetLocalListVersion is a helper method to define mock.On call

  • request *localauth.GetLocalListVersionRequest

func (*MockLocalAuthListChargePointHandler_Expecter) OnSendLocalList

OnSendLocalList is a helper method to define mock.On call

  • request *localauth.SendLocalListRequest

type MockLocalAuthListChargePointHandler_OnGetLocalListVersion_Call

type MockLocalAuthListChargePointHandler_OnGetLocalListVersion_Call struct {
	*mock.Call
}

MockLocalAuthListChargePointHandler_OnGetLocalListVersion_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OnGetLocalListVersion'

func (*MockLocalAuthListChargePointHandler_OnGetLocalListVersion_Call) Return

func (*MockLocalAuthListChargePointHandler_OnGetLocalListVersion_Call) Run

type MockLocalAuthListChargePointHandler_OnSendLocalList_Call

type MockLocalAuthListChargePointHandler_OnSendLocalList_Call struct {
	*mock.Call
}

MockLocalAuthListChargePointHandler_OnSendLocalList_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OnSendLocalList'

func (*MockLocalAuthListChargePointHandler_OnSendLocalList_Call) Return

func (*MockLocalAuthListChargePointHandler_OnSendLocalList_Call) Run

func (*MockLocalAuthListChargePointHandler_OnSendLocalList_Call) RunAndReturn

type MockLogCentralSystemHandler

type MockLogCentralSystemHandler struct {
	mock.Mock
}

MockLogCentralSystemHandler is an autogenerated mock type for the CentralSystemHandler type

func NewMockLogCentralSystemHandler

func NewMockLogCentralSystemHandler(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockLogCentralSystemHandler

NewMockLogCentralSystemHandler creates a new instance of MockLogCentralSystemHandler. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockLogCentralSystemHandler) EXPECT

func (*MockLogCentralSystemHandler) OnLogStatusNotification

func (_m *MockLogCentralSystemHandler) OnLogStatusNotification(chargingStationID string, request *logging.LogStatusNotificationRequest) (*logging.LogStatusNotificationResponse, error)

OnLogStatusNotification provides a mock function with given fields: chargingStationID, request

type MockLogCentralSystemHandler_Expecter

type MockLogCentralSystemHandler_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockLogCentralSystemHandler_Expecter) OnLogStatusNotification

func (_e *MockLogCentralSystemHandler_Expecter) OnLogStatusNotification(chargingStationID interface{}, request interface{}) *MockLogCentralSystemHandler_OnLogStatusNotification_Call

OnLogStatusNotification is a helper method to define mock.On call

  • chargingStationID string
  • request *logging.LogStatusNotificationRequest

type MockLogCentralSystemHandler_OnLogStatusNotification_Call

type MockLogCentralSystemHandler_OnLogStatusNotification_Call struct {
	*mock.Call
}

MockLogCentralSystemHandler_OnLogStatusNotification_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OnLogStatusNotification'

func (*MockLogCentralSystemHandler_OnLogStatusNotification_Call) Return

func (*MockLogCentralSystemHandler_OnLogStatusNotification_Call) Run

type MockLogChargePointHandler

type MockLogChargePointHandler struct {
	mock.Mock
}

MockLogChargePointHandler is an autogenerated mock type for the ChargePointHandler type

func NewMockLogChargePointHandler

func NewMockLogChargePointHandler(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockLogChargePointHandler

NewMockLogChargePointHandler creates a new instance of MockLogChargePointHandler. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockLogChargePointHandler) EXPECT

func (*MockLogChargePointHandler) OnGetLog

OnGetLog provides a mock function with given fields: request

type MockLogChargePointHandler_Expecter

type MockLogChargePointHandler_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockLogChargePointHandler_Expecter) OnGetLog

OnGetLog is a helper method to define mock.On call

  • request *logging.GetLogRequest

type MockLogChargePointHandler_OnGetLog_Call

type MockLogChargePointHandler_OnGetLog_Call struct {
	*mock.Call
}

MockLogChargePointHandler_OnGetLog_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OnGetLog'

func (*MockLogChargePointHandler_OnGetLog_Call) Return

func (*MockLogChargePointHandler_OnGetLog_Call) Run

func (*MockLogChargePointHandler_OnGetLog_Call) RunAndReturn

type MockRemoteTriggerCentralSystemHandler

type MockRemoteTriggerCentralSystemHandler struct {
	mock.Mock
}

MockRemoteTriggerCentralSystemHandler is an autogenerated mock type for the CentralSystemHandler type

func NewMockRemoteTriggerCentralSystemHandler

func NewMockRemoteTriggerCentralSystemHandler(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockRemoteTriggerCentralSystemHandler

NewMockRemoteTriggerCentralSystemHandler creates a new instance of MockRemoteTriggerCentralSystemHandler. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockRemoteTriggerCentralSystemHandler) EXPECT

type MockRemoteTriggerCentralSystemHandler_Expecter

type MockRemoteTriggerCentralSystemHandler_Expecter struct {
	// contains filtered or unexported fields
}

type MockRemoteTriggerChargePointHandler

type MockRemoteTriggerChargePointHandler struct {
	mock.Mock
}

MockRemoteTriggerChargePointHandler is an autogenerated mock type for the ChargePointHandler type

func NewMockRemoteTriggerChargePointHandler

func NewMockRemoteTriggerChargePointHandler(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockRemoteTriggerChargePointHandler

NewMockRemoteTriggerChargePointHandler creates a new instance of MockRemoteTriggerChargePointHandler. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockRemoteTriggerChargePointHandler) EXPECT

func (*MockRemoteTriggerChargePointHandler) OnTriggerMessage

OnTriggerMessage provides a mock function with given fields: request

type MockRemoteTriggerChargePointHandler_Expecter

type MockRemoteTriggerChargePointHandler_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockRemoteTriggerChargePointHandler_Expecter) OnTriggerMessage

OnTriggerMessage is a helper method to define mock.On call

  • request *remotetrigger.TriggerMessageRequest

type MockRemoteTriggerChargePointHandler_OnTriggerMessage_Call

type MockRemoteTriggerChargePointHandler_OnTriggerMessage_Call struct {
	*mock.Call
}

MockRemoteTriggerChargePointHandler_OnTriggerMessage_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OnTriggerMessage'

func (*MockRemoteTriggerChargePointHandler_OnTriggerMessage_Call) Return

func (*MockRemoteTriggerChargePointHandler_OnTriggerMessage_Call) Run

type MockReservationCentralSystemHandler

type MockReservationCentralSystemHandler struct {
	mock.Mock
}

MockReservationCentralSystemHandler is an autogenerated mock type for the CentralSystemHandler type

func NewMockReservationCentralSystemHandler

func NewMockReservationCentralSystemHandler(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockReservationCentralSystemHandler

NewMockReservationCentralSystemHandler creates a new instance of MockReservationCentralSystemHandler. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockReservationCentralSystemHandler) EXPECT

type MockReservationCentralSystemHandler_Expecter

type MockReservationCentralSystemHandler_Expecter struct {
	// contains filtered or unexported fields
}

type MockReservationChargePointHandler

type MockReservationChargePointHandler struct {
	mock.Mock
}

MockReservationChargePointHandler is an autogenerated mock type for the ChargePointHandler type

func NewMockReservationChargePointHandler

func NewMockReservationChargePointHandler(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockReservationChargePointHandler

NewMockReservationChargePointHandler creates a new instance of MockReservationChargePointHandler. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockReservationChargePointHandler) EXPECT

func (*MockReservationChargePointHandler) OnCancelReservation

OnCancelReservation provides a mock function with given fields: request

func (*MockReservationChargePointHandler) OnReserveNow

OnReserveNow provides a mock function with given fields: request

type MockReservationChargePointHandler_Expecter

type MockReservationChargePointHandler_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockReservationChargePointHandler_Expecter) OnCancelReservation

OnCancelReservation is a helper method to define mock.On call

  • request *reservation.CancelReservationRequest

func (*MockReservationChargePointHandler_Expecter) OnReserveNow

OnReserveNow is a helper method to define mock.On call

  • request *reservation.ReserveNowRequest

type MockReservationChargePointHandler_OnCancelReservation_Call

type MockReservationChargePointHandler_OnCancelReservation_Call struct {
	*mock.Call
}

MockReservationChargePointHandler_OnCancelReservation_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OnCancelReservation'

func (*MockReservationChargePointHandler_OnCancelReservation_Call) Return

func (*MockReservationChargePointHandler_OnCancelReservation_Call) Run

type MockReservationChargePointHandler_OnReserveNow_Call

type MockReservationChargePointHandler_OnReserveNow_Call struct {
	*mock.Call
}

MockReservationChargePointHandler_OnReserveNow_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OnReserveNow'

func (*MockReservationChargePointHandler_OnReserveNow_Call) Return

func (*MockReservationChargePointHandler_OnReserveNow_Call) Run

func (*MockReservationChargePointHandler_OnReserveNow_Call) RunAndReturn

type MockSecureFirmwareCentralSystemHandler

type MockSecureFirmwareCentralSystemHandler struct {
	mock.Mock
}

MockSecureFirmwareCentralSystemHandler is an autogenerated mock type for the CentralSystemHandler type

func NewMockSecureFirmwareCentralSystemHandler

func NewMockSecureFirmwareCentralSystemHandler(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockSecureFirmwareCentralSystemHandler

NewMockSecureFirmwareCentralSystemHandler creates a new instance of MockSecureFirmwareCentralSystemHandler. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockSecureFirmwareCentralSystemHandler) EXPECT

func (*MockSecureFirmwareCentralSystemHandler) OnSignedFirmwareStatusNotification

OnSignedFirmwareStatusNotification provides a mock function with given fields: chargingStationID, request

type MockSecureFirmwareCentralSystemHandler_Expecter

type MockSecureFirmwareCentralSystemHandler_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockSecureFirmwareCentralSystemHandler_Expecter) OnSignedFirmwareStatusNotification

func (_e *MockSecureFirmwareCentralSystemHandler_Expecter) OnSignedFirmwareStatusNotification(chargingStationID interface{}, request interface{}) *MockSecureFirmwareCentralSystemHandler_OnSignedFirmwareStatusNotification_Call

OnSignedFirmwareStatusNotification is a helper method to define mock.On call

  • chargingStationID string
  • request *securefirmware.SignedFirmwareStatusNotificationRequest

type MockSecureFirmwareCentralSystemHandler_OnSignedFirmwareStatusNotification_Call

type MockSecureFirmwareCentralSystemHandler_OnSignedFirmwareStatusNotification_Call struct {
	*mock.Call
}

MockSecureFirmwareCentralSystemHandler_OnSignedFirmwareStatusNotification_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OnSignedFirmwareStatusNotification'

func (*MockSecureFirmwareCentralSystemHandler_OnSignedFirmwareStatusNotification_Call) Run

type MockSecureFirmwareChargePointHandler

type MockSecureFirmwareChargePointHandler struct {
	mock.Mock
}

MockSecureFirmwareChargePointHandler is an autogenerated mock type for the ChargePointHandler type

func NewMockSecureFirmwareChargePointHandler

func NewMockSecureFirmwareChargePointHandler(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockSecureFirmwareChargePointHandler

NewMockSecureFirmwareChargePointHandler creates a new instance of MockSecureFirmwareChargePointHandler. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockSecureFirmwareChargePointHandler) EXPECT

func (*MockSecureFirmwareChargePointHandler) OnSignedUpdateFirmware

OnSignedUpdateFirmware provides a mock function with given fields: request

type MockSecureFirmwareChargePointHandler_Expecter

type MockSecureFirmwareChargePointHandler_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockSecureFirmwareChargePointHandler_Expecter) OnSignedUpdateFirmware

OnSignedUpdateFirmware is a helper method to define mock.On call

  • request *securefirmware.SignedUpdateFirmwareRequest

type MockSecureFirmwareChargePointHandler_OnSignedUpdateFirmware_Call

type MockSecureFirmwareChargePointHandler_OnSignedUpdateFirmware_Call struct {
	*mock.Call
}

MockSecureFirmwareChargePointHandler_OnSignedUpdateFirmware_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OnSignedUpdateFirmware'

func (*MockSecureFirmwareChargePointHandler_OnSignedUpdateFirmware_Call) Return

func (*MockSecureFirmwareChargePointHandler_OnSignedUpdateFirmware_Call) Run

type MockSecurityCentralSystemHandler

type MockSecurityCentralSystemHandler struct {
	mock.Mock
}

MockSecurityCentralSystemHandler is an autogenerated mock type for the CentralSystemHandler type

func NewMockSecurityCentralSystemHandler

func NewMockSecurityCentralSystemHandler(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockSecurityCentralSystemHandler

NewMockSecurityCentralSystemHandler creates a new instance of MockSecurityCentralSystemHandler. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockSecurityCentralSystemHandler) EXPECT

func (*MockSecurityCentralSystemHandler) OnSecurityEventNotification

OnSecurityEventNotification provides a mock function with given fields: chargingStationID, request

func (*MockSecurityCentralSystemHandler) OnSignCertificate

func (_m *MockSecurityCentralSystemHandler) OnSignCertificate(chargingStationID string, request *security.SignCertificateRequest) (*security.SignCertificateResponse, error)

OnSignCertificate provides a mock function with given fields: chargingStationID, request

type MockSecurityCentralSystemHandler_Expecter

type MockSecurityCentralSystemHandler_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockSecurityCentralSystemHandler_Expecter) OnSecurityEventNotification

func (_e *MockSecurityCentralSystemHandler_Expecter) OnSecurityEventNotification(chargingStationID interface{}, request interface{}) *MockSecurityCentralSystemHandler_OnSecurityEventNotification_Call

OnSecurityEventNotification is a helper method to define mock.On call

  • chargingStationID string
  • request *security.SecurityEventNotificationRequest

func (*MockSecurityCentralSystemHandler_Expecter) OnSignCertificate

func (_e *MockSecurityCentralSystemHandler_Expecter) OnSignCertificate(chargingStationID interface{}, request interface{}) *MockSecurityCentralSystemHandler_OnSignCertificate_Call

OnSignCertificate is a helper method to define mock.On call

  • chargingStationID string
  • request *security.SignCertificateRequest

type MockSecurityCentralSystemHandler_OnSecurityEventNotification_Call

type MockSecurityCentralSystemHandler_OnSecurityEventNotification_Call struct {
	*mock.Call
}

MockSecurityCentralSystemHandler_OnSecurityEventNotification_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OnSecurityEventNotification'

func (*MockSecurityCentralSystemHandler_OnSecurityEventNotification_Call) Return

func (*MockSecurityCentralSystemHandler_OnSecurityEventNotification_Call) Run

type MockSecurityCentralSystemHandler_OnSignCertificate_Call

type MockSecurityCentralSystemHandler_OnSignCertificate_Call struct {
	*mock.Call
}

MockSecurityCentralSystemHandler_OnSignCertificate_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OnSignCertificate'

func (*MockSecurityCentralSystemHandler_OnSignCertificate_Call) Return

func (*MockSecurityCentralSystemHandler_OnSignCertificate_Call) Run

func (*MockSecurityCentralSystemHandler_OnSignCertificate_Call) RunAndReturn

type MockSecurityChargePointHandler

type MockSecurityChargePointHandler struct {
	mock.Mock
}

MockSecurityChargePointHandler is an autogenerated mock type for the ChargePointHandler type

func NewMockSecurityChargePointHandler

func NewMockSecurityChargePointHandler(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockSecurityChargePointHandler

NewMockSecurityChargePointHandler creates a new instance of MockSecurityChargePointHandler. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockSecurityChargePointHandler) EXPECT

func (*MockSecurityChargePointHandler) OnCertificateSigned

OnCertificateSigned provides a mock function with given fields: request

type MockSecurityChargePointHandler_Expecter

type MockSecurityChargePointHandler_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockSecurityChargePointHandler_Expecter) OnCertificateSigned

OnCertificateSigned is a helper method to define mock.On call

  • request *security.CertificateSignedRequest

type MockSecurityChargePointHandler_OnCertificateSigned_Call

type MockSecurityChargePointHandler_OnCertificateSigned_Call struct {
	*mock.Call
}

MockSecurityChargePointHandler_OnCertificateSigned_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OnCertificateSigned'

func (*MockSecurityChargePointHandler_OnCertificateSigned_Call) Return

func (*MockSecurityChargePointHandler_OnCertificateSigned_Call) Run

func (*MockSecurityChargePointHandler_OnCertificateSigned_Call) RunAndReturn

type MockSmartChargingCentralSystemHandler

type MockSmartChargingCentralSystemHandler struct {
	mock.Mock
}

MockSmartChargingCentralSystemHandler is an autogenerated mock type for the CentralSystemHandler type

func NewMockSmartChargingCentralSystemHandler

func NewMockSmartChargingCentralSystemHandler(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockSmartChargingCentralSystemHandler

NewMockSmartChargingCentralSystemHandler creates a new instance of MockSmartChargingCentralSystemHandler. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockSmartChargingCentralSystemHandler) EXPECT

type MockSmartChargingCentralSystemHandler_Expecter

type MockSmartChargingCentralSystemHandler_Expecter struct {
	// contains filtered or unexported fields
}

type MockSmartChargingChargePointHandler

type MockSmartChargingChargePointHandler struct {
	mock.Mock
}

MockSmartChargingChargePointHandler is an autogenerated mock type for the ChargePointHandler type

func NewMockSmartChargingChargePointHandler

func NewMockSmartChargingChargePointHandler(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockSmartChargingChargePointHandler

NewMockSmartChargingChargePointHandler creates a new instance of MockSmartChargingChargePointHandler. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockSmartChargingChargePointHandler) EXPECT

func (*MockSmartChargingChargePointHandler) OnClearChargingProfile

OnClearChargingProfile provides a mock function with given fields: request

func (*MockSmartChargingChargePointHandler) OnGetCompositeSchedule

OnGetCompositeSchedule provides a mock function with given fields: request

func (*MockSmartChargingChargePointHandler) OnSetChargingProfile

OnSetChargingProfile provides a mock function with given fields: request

type MockSmartChargingChargePointHandler_Expecter

type MockSmartChargingChargePointHandler_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockSmartChargingChargePointHandler_Expecter) OnClearChargingProfile

OnClearChargingProfile is a helper method to define mock.On call

  • request *smartcharging.ClearChargingProfileRequest

func (*MockSmartChargingChargePointHandler_Expecter) OnGetCompositeSchedule

OnGetCompositeSchedule is a helper method to define mock.On call

  • request *smartcharging.GetCompositeScheduleRequest

func (*MockSmartChargingChargePointHandler_Expecter) OnSetChargingProfile

OnSetChargingProfile is a helper method to define mock.On call

  • request *smartcharging.SetChargingProfileRequest

type MockSmartChargingChargePointHandler_OnClearChargingProfile_Call

type MockSmartChargingChargePointHandler_OnClearChargingProfile_Call struct {
	*mock.Call
}

MockSmartChargingChargePointHandler_OnClearChargingProfile_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OnClearChargingProfile'

func (*MockSmartChargingChargePointHandler_OnClearChargingProfile_Call) Return

func (*MockSmartChargingChargePointHandler_OnClearChargingProfile_Call) Run

type MockSmartChargingChargePointHandler_OnGetCompositeSchedule_Call

type MockSmartChargingChargePointHandler_OnGetCompositeSchedule_Call struct {
	*mock.Call
}

MockSmartChargingChargePointHandler_OnGetCompositeSchedule_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OnGetCompositeSchedule'

func (*MockSmartChargingChargePointHandler_OnGetCompositeSchedule_Call) Return

func (*MockSmartChargingChargePointHandler_OnGetCompositeSchedule_Call) Run

type MockSmartChargingChargePointHandler_OnSetChargingProfile_Call

type MockSmartChargingChargePointHandler_OnSetChargingProfile_Call struct {
	*mock.Call
}

MockSmartChargingChargePointHandler_OnSetChargingProfile_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OnSetChargingProfile'

func (*MockSmartChargingChargePointHandler_OnSetChargingProfile_Call) Return

func (*MockSmartChargingChargePointHandler_OnSetChargingProfile_Call) Run

Source Files

  • mock_certificates_charge_point_handler.go
  • mock_core_central_system_handler.go
  • mock_core_charge_point_handler.go
  • mock_extended_trigger_message_charge_point_handler.go
  • mock_firmware_central_system_handler.go
  • mock_firmware_charge_point_handler.go
  • mock_local_auth_list_central_system_handler.go
  • mock_local_auth_list_charge_point_handler.go
  • mock_logging_central_system_handler.go
  • mock_logging_charge_point_handler.go
  • mock_ocpp16.go
  • mock_remote_trigger_central_system_handler.go
  • mock_remote_trigger_charge_point_handler.go
  • mock_reservation_central_system_handler.go
  • mock_reservation_charge_point_handler.go
  • mock_secure_firmware_CentralSystemHandler.go
  • mock_secure_firmware_ChargePointHandler.go
  • mock_security_central_system_handler.go
  • mock_security_charge_point_handler.go
  • mock_smart_charging_central_system_handler.go
  • mock_smart_charging_charge_point_handler.go

Jump to